@@ -31,6 +31,8 @@ process.each.file <- function(study){
   .QC$thisStudy$starttime <- Sys.time()
 
   .QC$thisStudy$number <- .QC$file.counter
+  .QC$thisStudy$effect_type_string <- .QC$config$input_parameters$effect_type_string
+
   .QC$file.counter <- .QC$file.counter + 1 ## counter that displays how many files are processed
 
   #print.and.log(mem_used(),'info',cat= FALSE)
@@ -170,6 +172,18 @@ process.each.file <- function(study){
   # selcet high quality variants based on 4 filters
   input.data <- applyHQfilter(input.data) #calculationFunctions.R
 
+
+  # generate distribution statistcis for HQ variants
+  # summary of important columns
+  if(.QC$thisStudy$HQ.count == .QC$thisStudy$rowcount.step3)
+  {
+    .QC$thisStudy$tables$variable.summary.HQ <- .QC$thisStudy$tables$variable.summary
+  }
+  else if(.QC$thisStudy$HQ.count > 0)
+  {
+    .QC$thisStudy$tables$variable.summary.HQ <- variable.statistics.post.matching_HQ(input.data)
+  }
+
   ##TODO  outliers are defined as skewness > 0.1 or < -0.1, or kurtosis > 10
   calculateSkewness(input.data)
   calculateSkewness.HQ(input.data)
@@ -362,30 +376,36 @@ process.each.file <- function(study){
     }
 
 
-    write(x = '\n\n[Comparing Input File with Effect-size reference dataset (HQ variants)]',
-        file = .QC$thisStudy$txt.report.path ,
-        sep =  '\n',
-        append = TRUE)
+    # write(x = '\n\n[Comparing Input File with Effect-size reference dataset (HQ variants)]',
+    #     file = .QC$thisStudy$txt.report.path ,
+    #     sep =  '\n',
+    #     append = TRUE)
 
-    write(x = paste('r (P-value < 0.001) =' ,  .QC$thisStudy$effect.rho_3),
-        file = .QC$thisStudy$txt.report.path ,
-        sep =  '\n',
-        append = TRUE)
+    writeTXTreport('\n\nComparing Input File with Effect-size reference dataset (HQ variants)')
+    writeTXTreport(kable(.QC$thisStudy$tables$betaCor.tbl, align = "l",format = "rst"))
 
-    write(x = paste('r (P-value < 0.0001) =' ,  .QC$thisStudy$effect.rho_4),
-        file = .QC$thisStudy$txt.report.path ,
-        sep =  '\n',
-        append = TRUE)
+    writeTXTreport('\n* Data is presented as r(N). Variants were filtered on reference data P-values. ')
+    writeTXTreport('** Data is presented as r(N). Variants were filtered on input result file P-values. ')
 
-    write(x = paste('r (P-value < 0.00001) =' ,  .QC$thisStudy$effect.rho_5),
-	    file = .QC$thisStudy$txt.report.path ,
-	    sep =  '\n',
-	    append = TRUE)
-
-    write(x = paste('r (P-value < 0.000001) =' ,  .QC$thisStudy$effect.rho_6),
-	    file = .QC$thisStudy$txt.report.path ,
-	    sep =  '\n',
-	    append = TRUE)
+#     write(x = paste('r (P-value < 0.001) =' ,  .QC$thisStudy$effect.rho_3),
+#         file = .QC$thisStudy$txt.report.path ,
+#         sep =  '\n',
+#         append = TRUE)
+#
+#     write(x = paste('r (P-value < 0.0001) =' ,  .QC$thisStudy$effect.rho_4),
+#         file = .QC$thisStudy$txt.report.path ,
+#         sep =  '\n',
+#         append = TRUE)
+#
+#     write(x = paste('r (P-value < 0.00001) =' ,  .QC$thisStudy$effect.rho_5),
+# 	    file = .QC$thisStudy$txt.report.path ,
+# 	    sep =  '\n',
+# 	    append = TRUE)
+#
+#     write(x = paste('r (P-value < 0.000001) =' ,  .QC$thisStudy$effect.rho_6),
+# 	    file = .QC$thisStudy$txt.report.path ,
+# 	    sep =  '\n',
+# 	    append = TRUE)
 
   }
 
@@ -408,6 +428,11 @@ process.each.file <- function(study){
   ##==============
   print.and.log('\n','info')
 
+  ## add info to text report
+  writeTXTreport("\n==============================================")
+  writeTXTreport(sprintf('Generated by %s package - v.%s',.QC$package.name, .QC$script.version))
+  writeTXTreport(as.character(Sys.time()))
+
   return(.QC$thisStudy)
 }
 
@@ -706,6 +731,7 @@ create.file.specific.config <- function(file.name){
   study$tables$imputed.tbl <-  as.data.table(matrix(NA,2,2))
   study$tables$multi_allele_count_preProcess <- data.table()
   study$tables$multi_allele_count_postProcess <- data.table()
+  study$tables$variable.summary.HQ <- data.table()
 
   colnames(study$tables$imputed.tbl) <- c('IMPUTED','N')
   study$tables$imputed.tbl$IMPUTED[1] <- 'Imputed'
@@ -906,9 +932,9 @@ get.file.line.count_RUtils <- function(file.path)
                    scientific = FALSE)
 
     return(list(line,file_ends_withNewline))
-    },
-    error = function(err) return("NA (command not accessible)","NA")
-    )
+  },
+  error = function(err) return("NA (command not accessible)","NA")
+  )
 
   return(file.line.count)
 }
@@ -1068,6 +1094,24 @@ variable.statistics.post.matching <- function(input.data)
 
 }
 
+variable.statistics.post.matching_HQ <- function(input.data)
+{
+
+  existing.columns <- intersect(c('PVALUE','HWE_PVAL','CALLRATE','EFF_ALL_FREQ','IMP_QUALITY','EFFECT','STDERR') ,
+                                names(input.data))
+
+  tbl <- cbind(sapply(input.data[HQ == 1,existing.columns,with= FALSE],
+                                                        function(x) return(summary(x)[1:6])))
+
+  tbl <- formatC(tbl, format = 'g')
+
+
+  # change effect column name to BETA or LN(OR)
+  colnames(tbl)[colnames(tbl) == 'EFFECT'] <- .QC$config$input_parameters$effect_type_string
+
+  return(tbl)
+}
+
 
 addEmptyStudy_studyInstance <- function(study)
 {
